==> haskell-memory-0.14.8-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-memory.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: memory
version: 0.14.8
id: memory-0.14.8-BAg3DtPwumR3TQfKUohmeR
key: memory-0.14.8-BAg3DtPwumR3TQfKUohmeR
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org, Nicolas Di Prima <nicolas@primetype.co.uk>
stability: experimental
homepage: https://github.com/vincenthz/hs-memory
synopsis: memory and related abstraction stuff
description:
    Chunk of memory, polymorphic byte array management and manipulation
    .
    * A polymorphic byte array abstraction and function similar to strict ByteString.
    .
    * Different type of byte array abstraction.
    .
    * Raw memory IO operations (memory set, memory copy, ..)
    .
    * Aliasing with endianness support.
    .
    * Encoding : Base16, Base32, Base64.
    .
    * Hashing : FNV, SipHash
category: memory
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.ByteArray Data.ByteArray.Encoding Data.ByteArray.Hash
    Data.ByteArray.Mapping Data.ByteArray.Pack Data.ByteArray.Parse
    Data.Memory.Encoding.Base16 Data.Memory.Encoding.Base32
    Data.Memory.Encoding.Base64 Data.Memory.Endian
    Data.Memory.ExtendedWords Data.Memory.PtrMethods
hidden-modules: Data.Memory.Internal.Compat
                Data.Memory.Internal.CompatPrim Data.Memory.Internal.CompatPrim64
                Data.Memory.Internal.DeepSeq Data.Memory.Internal.Imports
                Data.Memory.Internal.Scrubber Data.Memory.Hash.SipHash
                Data.Memory.Hash.FNV Data.ByteArray.Pack.Internal
                Data.ByteArray.Types Data.ByteArray.Bytes
                Data.ByteArray.ScrubbedBytes Data.ByteArray.Methods
                Data.ByteArray.MemView Data.ByteArray.View Data.Memory.MemMap.Posix
abi: b78231a975bde8739839c13c0576fe77
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/memory-0.14.8
library-dirs: /usr/lib/ghc-8.2.1/site-local/memory-0.14.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/memory-0.14.8
hs-libraries: HSmemory-0.14.8-BAg3DtPwumR3TQfKUohmeR
depends:
    base-4.10.0.0 ghc-prim-0.5.1.0 bytestring-0.10.8.2 deepseq-1.4.3.0
    foundation-0.0.17-LXSmYRpWiir1Zb44YS0jRo
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             ghc-prim-0.5.1.0=557c7fce76ef13c2417583cc28848f14
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             deepseq-1.4.3.0=15f2832424b38ea5b23f1ebc9071dcc3
             foundation-0.0.17-LXSmYRpWiir1Zb44YS0jRo=8054f077d78bddbe3a8de5ab1f6ebf09
haddock-interfaces: /usr/share/doc/haskell-memory/html/memory.haddock
haddock-html: /usr/share/doc/haskell-memory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memory-0.14.9-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-memory.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: memory
version: 0.14.9
id: memory-0.14.9-AQUrr5dF0nV994F583HdFJ
key: memory-0.14.9-AQUrr5dF0nV994F583HdFJ
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org, Nicolas Di Prima <nicolas@primetype.co.uk>
stability: experimental
homepage: https://github.com/vincenthz/hs-memory
synopsis: memory and related abstraction stuff
description:
    Chunk of memory, polymorphic byte array management and manipulation
    .
    * A polymorphic byte array abstraction and function similar to strict ByteString.
    .
    * Different type of byte array abstraction.
    .
    * Raw memory IO operations (memory set, memory copy, ..)
    .
    * Aliasing with endianness support.
    .
    * Encoding : Base16, Base32, Base64.
    .
    * Hashing : FNV, SipHash
category: memory
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.ByteArray Data.ByteArray.Encoding Data.ByteArray.Hash
    Data.ByteArray.Mapping Data.ByteArray.Pack Data.ByteArray.Parse
    Data.Memory.Encoding.Base16 Data.Memory.Encoding.Base32
    Data.Memory.Encoding.Base64 Data.Memory.Endian
    Data.Memory.ExtendedWords Data.Memory.PtrMethods
hidden-modules: Data.Memory.Internal.Compat
                Data.Memory.Internal.CompatPrim Data.Memory.Internal.CompatPrim64
                Data.Memory.Internal.DeepSeq Data.Memory.Internal.Imports
                Data.Memory.Internal.Scrubber Data.Memory.Hash.SipHash
                Data.Memory.Hash.FNV Data.ByteArray.Pack.Internal
                Data.ByteArray.Types Data.ByteArray.Bytes
                Data.ByteArray.ScrubbedBytes Data.ByteArray.Methods
                Data.ByteArray.MemView Data.ByteArray.View Data.Memory.MemMap.Posix
abi: 008982010396ecb5861316ba65cfe759
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/memory-0.14.9
library-dirs: /usr/lib/ghc-8.2.2/site-local/memory-0.14.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/memory-0.14.9
hs-libraries: HSmemory-0.14.9-AQUrr5dF0nV994F583HdFJ
depends:
    base-4.10.1.0 ghc-prim-0.5.1.1
    basement-0.0.4-7pJikASNmAFFwadsMZ0ihV bytestring-0.10.8.2
    deepseq-1.4.3.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             ghc-prim-0.5.1.1=84323a6edd008b04bf217464a4ccaf16
             basement-0.0.4-7pJikASNmAFFwadsMZ0ihV=be651ecbcc5a259a3ed39508edf1122b
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             deepseq-1.4.3.0=e843b5d736cc095915bf2399fddf152e
haddock-interfaces: /usr/share/doc/haskell-memory/html/memory.haddock
haddock-html: /usr/share/doc/haskell-memory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
